<?php
/* $Id: russian-windows-1251.inc.php,v 2.78 2005/07/29 17:03:21 lem9 Exp $ */

/**
 * Translated by Gosha Sakovich <gt2 at users.sourceforge.net>
 *               Artyom Rabzonov <tyomych at gmx.net>
 *               Nicolay Zakharov <info at melody.org.ru> 16-Dec-2002
 *               (nobody) 2004-09-18
 */

$charset = 'windows-1251';
$text_dir = 'ltr';
$left_font_family = 'sans-serif';
$right_font_family = 'sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
//$byteUnits = array('', '', '', '');
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('', '', '', '', '', '', '');
$month = array('', '', '', '', '', '', '', '', '', '', '', '');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d %Y ., %H:%M';
$timespanfmt = '%s , %s , %s   %s ';

$strAPrimaryKey = '     %s';
$strAbortedClients = '';
$strAbsolutePathToDocSqlDir = '       docSQL, ';
$strAccessDenied = '  ';
$strAccessDeniedExplanation = 'phpMyAdmin     MySQL,    .   ,     config.inc.php.';
$strAction = '';
$strAddAutoIncrement = '  AUTO_INCREMENT';
$strAddConstraints = ' ';
$strAddDeleteColumn = '/  ';
$strAddDeleteRow = '/  ';
$strAddDropDatabase = ' DROP DATABASE';
$strAddHeaderComment = '    header (\\n  )';
$strAddIfNotExists = ' IF NOT EXISTS';
$strAddIntoComments = '  ';
$strAddNewField = '  ';
$strAddPrivilegesOnDb = '    ';
$strAddPrivilegesOnTbl = '     ';
$strAddSearchConditions = '   (   "where"):';
$strAddToIndex = '  &nbsp;%s&nbsp;()';
$strAddUser = '  ';
$strAddUserMessage = '   .';
$strAddedColumnComment = '   ';
$strAddedColumnRelation = '   ';
$strAdministration = '';
$strAffectedRows = ' :';
$strAfter = ' %s';
$strAfterInsertBack = '';
$strAfterInsertNewInsert = '  ';
$strAfterInsertSame = '   ';
$strAll = '';
$strAllTableSameWidth = '     ?';
$strAlterOrderBy = '  ';
$strAnIndex = '    %s';
$strAnalyzeTable = ' ';
$strAnd = '';
$strAny = '';
$strAnyHost = ' ';
$strAnyUser = ' ';
$strArabic = '';
$strArmenian = '';
$strAscending = ' ';
$strAtBeginningOfTable = '  ';
$strAtEndOfTable = '  ';
$strAttr = '';
$strAutodetect = '';
$strAutomaticLayout = ' ';

$strBack = '';
$strBaltic = '';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = '  ';
$strBinaryDoNotEdit = '   -   ';
$strBookmarkAllUsers = '     ';
$strBookmarkDeleted = '  .';
$strBookmarkLabel = '';
$strBookmarkOptions = ' ';
$strBookmarkQuery = '  SQL-';
$strBookmarkThis = '   SQL-';
$strBookmarkView = ' ';
$strBrowse = '';
$strBrowseForeignValues = 'Browse foreign values';
$strBulgarian = '';
$strBzError = 'phpMyAdmin     -   Bz2 extension    PHP.     <code>$cfg[\'BZipDump\']</code>     phpMyAdmin  <code>FALSE</code>.     Bz2-,    PHP.  PHP bug report %s    .';
$strBzip = '  bzip';

$strCSVOptions = ' CSV';
$strCalendar = '';
$strCannotLogin = '   MySQL';
$strCantLoad = '    %s,<br />  PHP, ';
$strCantLoadRecodeIconv = '   iconv  recode,    .  php-          phpMyAdmin.';
$strCantRenameIdxToPrimary = '    PRIMARY!';
$strCantUseRecodeIconv = '   iconv :  libiconv,  recode_string,     extension reports.  php-.';
$strCardinality = ' ';
$strCarriage = ' : \\r';
$strCaseInsensitive = '  ';
$strCaseSensitive = '   ';
$strCentralEuropean = '-';
$strChange = '';
$strChangeCopyMode = '        ...';
$strChangeCopyModeCopy = '...  .';
$strChangeCopyModeDeleteAndReload = ' ...        .';
$strChangeCopyModeJustDelete = ' ...     .';
$strChangeCopyModeRevoke = ' ...         .';
$strChangeCopyUser = '  /  ';
$strChangeDisplay = '   ';
$strChangePassword = ' ';
$strCharset = '';
$strCharsetOfFile = ' :';
$strCharsets = '';
$strCharsetsAndCollations = '  ';
$strCheckAll = ' ';
$strCheckOverhead = '  ';
$strCheckPrivs = ' ';
$strCheckPrivsLong = '    &quot;%s&quot;.';
$strCheckTable = ' ';
$strChoosePage = '   ';
$strColComFeat = '  ';
$strCollation = '';
$strColumnNames = ' ';
$strColumnPrivileges = ',   ';
$strCommand = '';
$strComments = '';
$strCommentsForTable = '  ';
$strCompleteInserts = ' ';
$strCompression = '';
$strConfigFileError = 'phpMyAdmin       !  <br />  -  .<br />   (config.inc.php)   .      -  .    -   ';
$strConfigureTableCoord = '   %s';
$strConnectionError = ' :  .';
$strConnections = '';
$strConstraintsForDumped = 'Constraints for dumped tables';
$strConstraintsForTable = 'Constraints for table';
$strCookiesRequired = 'Cookies      .';
$strCopyTable = '   ( <b>.</b>):';
$strCopyTableOK = ' %s    %s.';
$strCopyTableSameNames = '        !';
$strCouldNotKill = 'phpMyAdmin    thread %s. ,   .';
$strCreate = '';
$strCreateIndex = '  &nbsp;%s&nbsp;';
$strCreateIndexTopic = '  ';
$strCreateNewDatabase = '  ';
$strCreateNewTable = '     %s';
$strCreatePage = '  ';
$strCreatePdfFeat = ' PDF-';
$strCreationDates = '// ';
$strCriteria = '';
$strCroatian = '';
$strCyrillic = '';
$strCzech = '';
$strCzechSlovak = '';

$strDBComment = ' : ';
$strDBGContext = '';
$strDBGContextID = ' ID';
$strDBGHits = 'Hits';
$strDBGLine = 'Line';
$strDBGMaxTimeMs = ' , ms';
$strDBGMinTimeMs = ' , ms';
$strDBGModule = '';
$strDBGTimePerHitMs = 'Time/Hit, ms';
$strDBGTotalTimeMs = ' , ms';
$strDBRename = '   ';
$strDanish = '';
$strData = '';
$strDataDict = ' ';
$strDataOnly = ' ';
$strDatabase = '';
$strDatabaseEmpty = '    !';
$strDatabaseExportOptions = '  ';
$strDatabaseHasBeenDropped = '  %s  .';
$strDatabaseNoTable = '    !';
$strDatabases = ' ';
$strDatabasesDropped = '%s    .';
$strDatabasesStats = '  ';
$strDatabasesStatsDisable = ' ';
$strDatabasesStatsEnable = ' ';
$strDatabasesStatsHeavyTraffic = ':          -   MySQL.';
$strDbPrivileges = ' ,    ';
$strDbSpecific = '  ';
$strDefault = ' ';
$strDefaultValueHelp = '           ,   : a';
$strDefragment = ' ';
$strDelOld = '      ,    .     ?';
$strDelayedInserts = '  ';
$strDelete = '';
$strDeleteAndFlush = '     .';
$strDeleteAndFlushDescr = '  ,       .';
$strDeleted = '  ';
$strDeletedRows = '   :';
$strDeleting = ' %s';
$strDescending = ' ';
$strDescription = '';
$strDictionary = '';
$strDisableForeignChecks = '   ';
$strDisabled = '';
$strDisplayFeat = '  ';
$strDisplayOrder = ' :';
$strDisplayPDF = ' PDF-';
$strDoAQuery = ' "  " ( : "%")';
$strDoYouReally = '   ';
$strDocu = '';
$strDrop = '';
$strDropDatabaseStrongWarning = '       ?';
$strDropSelectedDatabases = '  ';
$strDropUsersDb = ' ,        .';
$strDumpSaved = '    %s.';
$strDumpXRows = ' %s ,   %s.';
$strDumpingData = '  ';
$strDynamic = '';

$strEdit = '';
$strEditPDFPages = ' PDF-';
$strEditPrivileges = ' ';
$strEffective = '';
$strEmpty = '';
$strEmptyResultSet = 'MySQL    (..  ).';
$strEnabled = '';
$strEncloseInTransaction = '  ';
$strEnd = '';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnglish = '';
$strEnglishPrivileges = ' :  MySQL  - ';
$strError = '';
$strEstonian = '';
$strExcelEdition = 'Excel-';
$strExcelOptions = ' Excel';
$strExecuteBookmarked = '  ';
$strExplain = ' SQL';
$strExport = '';
$strExtendedInserts = ' ';
$strExtra = '';

$strFailedAttempts = ' ';
$strField = '';
$strFieldHasBeenDropped = ' %s  ';
$strFields = '';
$strFieldsEmpty = '   ! ';
$strFieldsEnclosedBy = '  ';
$strFieldsEscapedBy = ' ';
$strFieldsTerminatedBy = ' ';
$strFileAlreadyExists = ' %s    ,      .';
$strFileCouldNotBeRead = '    ';
$strFileNameTemplate = '  ';
$strFileNameTemplateHelp = ' __DB__   , __TABLE__     %s  strftime%s    ,    .     .';
$strFileNameTemplateRemember = ' ';
$strFixed = '';
$strFlushPrivilegesNote = ': phpMyAdmin        MySQL.        ,   ,     .      %s %s   .';
$strFlushTable = '   ("FLUSH")';
$strFormEmpty = '   !';
$strFormat = '';
$strFullText = ' ';
$strFunction = '';

$strGenBy = '';
$strGenTime = ' ';
$strGeneralRelationFeat = '  ';
$strGeorgian = '';
$strGerman = '';
$strGlobal = 'global';
$strGlobalPrivileges = ' ';
$strGlobalValue = ' ';
$strGo = '';
$strGrantOption = '';
$strGreek = '';
$strGzip = '  gzip';

$strHasBeenAltered = ' .';
$strHasBeenCreated = ' .';
$strHaveToShow = '        ';
$strHebrew = '';
$strHexForBinary = '  (hexadecimal)  ';
$strHome = ' ';
$strHomepageOfficial = '  phpMyAdmin';
$strHost = '';
$strHostEmpty = '  !';
$strHungarian = '';

$strIcelandic = '';
$strId = 'ID';
$strIdxFulltext = '';
$strIfYouWish = '       ,     .';
$strIgnore = '';
$strIgnoreInserts = ' ';
$strIgnoringFile = '  %s';
$strImportDocSQL = ' docSQL ';
$strImportFiles = ' ';
$strImportFinished = ' ';
$strInUse = '';
$strIndex = '';
$strIndexHasBeenDropped = ' %s  ';
$strIndexName = ' &nbsp;:';
$strIndexType = ' &nbsp;:';
$strIndexes = '';
$strInnodbStat = 'InnoDB ';
$strInsecureMySQL = '     ( root  ),      MySQL ( ).  MySQL       ,   ,         .';
$strInsert = '';
$strInsertAsNewRow = '  ';
$strInsertNewRow = '  ';
$strInsertTextfiles = '    ';
$strInsertedRowId = ' id :';
$strInsertedRows = ' :';
$strInstructions = '';
$strInternalNotNecessary = '*    ,      InnoDB.';
$strInternalRelations = ' ';

$strJapanese = '';
$strJumpToDB = '   &quot;%s&quot;.';
$strJustDelete = '     .';
$strJustDeleteDescr = '&quot;&quot;             .';

$strKeepPass = '  ';
$strKeyname = ' ';
$strKill = '';
$strKorean = '';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = ' LaTeX';
$strLandscape = '';
$strLatexCaption = ' ';
$strLatexContent = '  __TABLE__';
$strLatexContinued = '()';
$strLatexContinuedCaption = '  ';
$strLatexIncludeCaption = '  ';
$strLatexLabel = 'Label key';
$strLatexStructure = '  __TABLE__';
$strLatvian = '';
$strLengthSet = '/*';
$strLimitNumRows = '  ';
$strLineFeed = '  : \\n';
$strLinesTerminatedBy = ' ';
$strLinkNotFound = '  ';
$strLinksTo = ' ';
$strLithuanian = '';
$strLoadExplanation = '    ,     ,    .';
$strLoadMethod = ' LOAD';
$strLocalhost = 'Local';
$strLocationTextfile = '  ';
$strLogPassword = ':';
$strLogServer = '';
$strLogUsername = ':';
$strLogin = '  ';
$strLoginInformation = ' ';
$strLogout = '  ';

$strMIMETypesForTable = 'MIME- ';
$strMIME_MIMEtype = 'MIME-';
$strMIME_available_mime = ' MIME-';
$strMIME_available_transform = ' ';
$strMIME_description = '';
$strMIME_nodescription = '     .<br />,     %s.';
$strMIME_transformation = ' ';
$strMIME_transformation_note = '        MIME-   %s %s';
$strMIME_transformation_options = ' ';
$strMIME_transformation_options_note = ',    ,   : \'a\',\'b\',\'c\'...<br />    ("\")  ("\'"),   ( \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME-,  ,     ';
$strMaximumSize = ' : %s%s';
$strModifications = '  ';
$strModify = '';
$strModifyIndexTopic = ' ';
$strMoreStatusVars = '  ';
$strMoveTable = '   ( <b>.</b>):';
$strMoveTableOK = ' %s    %s.';
$strMoveTableSameNames = '      !';
$strMultilingual = '';
$strMustSelectFile = '     .';
$strMySQLCharset = 'MySQL-';
$strMySQLConnectionCollation = '   MySQL';
$strMySQLReloaded = 'MySQL .';
$strMySQLSaid = ' MySQL: ';
$strMySQLServerProcess = 'MySQL %pma_s1%  %pma_s2%  %pma_s3%';
$strMySQLShowProcess = ' ';
$strMySQLShowStatus = '  MySQL';
$strMySQLShowVars = '   MySQL';

$strName = '';
$strNeedPrimaryKey = '      .';
$strNext = '';
$strNo = '';
$strNoDatabases = ' ';
$strNoDatabasesSelected = '    .';
$strNoDescription = ' ';
$strNoDropDatabases = ' " " .';
$strNoExplain = '  SQL';
$strNoFrames = '  phpMyAdmin     <b></b>.';
$strNoIndex = '  !';
$strNoIndexPartsDefined = '   !';
$strNoModification = ' ';
$strNoOptions = '    ';
$strNoPassword = ' ';
$strNoPermission = '-       %s.';
$strNoPhp = ' PHP-';
$strNoPrivileges = ' ';
$strNoQuery = ' SQL-!';
$strNoRights = '      !';
$strNoRowsSelected = '   ';
$strNoSpace = '       %s.';
$strNoTablesFound = '    .';
$strNoUsersFound = '  .';
$strNoValidateSQL = '  SQL';
$strNone = '';
$strNotNumber = '  !';
$strNotOK = ' ';
$strNotSet = ' <b>%s</b>  ';
$strNull = '';
$strNumSearchResultsInTable = '%s ()   <i>%s</i>';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ()';
$strNumTables = '';

$strOK = '';
$strOftenQuotation = ' . " " ,    char  varchar   .';
$strOperations = '';
$strOperator = '';
$strOptimizeTable = ' ';
$strOptionalControls = ' .       .';
$strOptionally = ' ';
$strOr = '';
$strOverhead = ' ';
$strOverwriteExisting = ' () ()';

$strPHP40203 = '   PHP 4.2.3,        -  (mbstring).  PHP bug report 19404.   PHP      phpMyAdmin.';
$strPHPVersion = ' PHP';
$strPageNumber = ' :';
$strPaperSize = ' ';
$strPartialText = ' ';
$strPassword = '';
$strPasswordChanged = '  %s   .';
$strPasswordEmpty = ' !';
$strPasswordNotSame = '  !';
$strPdfDbSchema = '  "%s" -  %s';
$strPdfInvalidTblName = ' "%s"  !';
$strPdfNoTables = ' ';
$strPerHour = ' ';
$strPerMinute = ' ';
$strPerSecond = ' ';
$strPhoneBook = ' ';
$strPhp = ' PHP-';
$strPmaDocumentation = '  phpMyAdmin';
$strPmaUriError = ' <tt>$cfg[\'PmaAbsoluteUri\']</tt>       !';
$strPolish = '';
$strPortrait = '';
$strPos1 = '';
$strPrevious = '';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = '   ';
$strPrimaryKeyName = '     PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b></b>   <b></b>  !)';
$strPrint = '';
$strPrintView = '  ';
$strPrintViewFull = ' (  )';
$strPrivDescAllPrivileges = 'Includes all privileges except GRANT.';
$strPrivDescAlter = '    .';
$strPrivDescCreateDb = '      .';
$strPrivDescCreateTbl = '   .';
$strPrivDescCreateTmpTable = '   .';
$strPrivDescDelete = '  .';
$strPrivDescDropDb = '  ';
$strPrivDescDropTbl = '  .';
$strPrivDescExecute = '   ;      MySQL.';
$strPrivDescFile = '      .';
$strPrivDescGrant = '        .';
$strPrivDescIndex = '    .';
$strPrivDescInsert = '    .';
$strPrivDescLockTables = '     .';
$strPrivDescMaxConnections = '  ,       .';
$strPrivDescMaxQuestions = '  ,       .';
$strPrivDescMaxUpdates = '  ,      ,      .';
$strPrivDescProcess3 = '    .';
$strPrivDescProcess4 = '      .';
$strPrivDescReferences = '     MySQL.';
$strPrivDescReload = '       .';
$strPrivDescReplClient = '      slaves / masters.';
$strPrivDescReplSlave = '   slaves.';
$strPrivDescSelect = '  .';
$strPrivDescShowDb = '      .';
$strPrivDescShutdown = '  .';
$strPrivDescSuper = ' ,      ;     ,          .';
$strPrivDescUpdate = '  .';
$strPrivDescUsage = ' .';
$strPrivileges = '';
$strPrivilegesReloaded = '   .';
$strProcesslist = ' ';
$strPutColNames = '     ';

$strQBE = '&nbsp;&nbsp;';
$strQBEDel = '';
$strQBEIns = '';
$strQueryFrame = ' ';
$strQueryOnDb = 'SQL-  <b>%s</b>:';
$strQuerySQLHistory = ' SQL';
$strQueryStatistics = '<b> </b>:    %s     .';
$strQueryTime = '  %01.4f ';
$strQueryType = ' ';
$strQueryWindowLock = '     ';

$strReType = '';
$strReceived = '';
$strRecords = '';
$strReferentialIntegrity = '  :';
$strRefresh = '';
$strRelationNotWorking = '       .     %s%s.';
$strRelationView = ' ';
$strRelationalSchema = ' ';
$strRelations = '';
$strRelationsForTable = '  ';
$strReloadFailed = '   MySQL.';
$strReloadMySQL = ' MySQL';
$strReloadingThePrivileges = ' ';
$strRemoveSelectedUsers = '  ';
$strRenameDatabaseOK = '  %s   %s';
$strRenameTable = '  ';
$strRenameTableOK = ' %s    %s';
$strRepairTable = ' ';
$strReplace = '';
$strReplaceNULLBy = ' NULL ';
$strReplaceTable = '     ';
$strReset = '';
$strResourceLimits = ' ';
$strRevoke = '';
$strRevokeAndDelete = '        .';
$strRevokeAndDeleteDescr = '     USAGE    .';
$strRevokeMessage = '    %s';
$strRomanian = '';
$strRowLength = ' ';
$strRowSize = '   ';
$strRows = '';
$strRowsFrom = ' ';
$strRowsModeFlippedHorizontal = '( )';
$strRowsModeHorizontal = '';
$strRowsModeOptions = ' %s ,    %s ';
$strRowsModeVertical = '';
$strRowsStatistic = ' ';
$strRunQuery = ' ';
$strRunSQLQuery = ' SQL ()   %';
$strRunning = ' %s';
$strRussian = '';

$strSQL = 'SQL';
$strSQLExportType = ' ';
$strSQLOptions = ' SQL';
$strSQLParserBugMessage = '     SQL-. ,       .  ,         quoted text area.           MySQL.   MySQL   ,    ,   .             ,      ,    SQL      ,    .            ( CUT):';
$strSQLParserUserError = '     SQL .    MySQL   , ,    ';
$strSQLQuery = 'SQL-';
$strSQLResult = 'SQL-';
$strSQPBugInvalidIdentifer = ' ';
$strSQPBugUnclosedQuote = ' ';
$strSQPBugUnknownPunctuation = '   ';
$strSave = '';
$strSaveOnServer = '     %s';
$strScaleFactorSmall = '         ';
$strSearch = '';
$strSearchFormTitle = '   ';
$strSearchInTables = ' ():';
$strSearchNeedle = '()  ()   ( "%") :';
$strSearchOption1 = '  ';
$strSearchOption2 = ' ';
$strSearchOption3 = ' ';
$strSearchOption4 = ' ';
$strSearchResultsFor = '  "<i>%s</i>" %s:';
$strSearchType = ':';
$strSecretRequired = '      (blowfish_secret).';
$strSelectADb = ' ';
$strSelectAll = ' ';
$strSelectFields = '  ( ):';
$strSelectNumRows = ' ';
$strSelectTables = ' ()';
$strSend = '';
$strSent = '';
$strServer = '';
$strServerChoice = ' ';
$strServerNotResponding = '  ';
$strServerStatus = ' ';
$strServerStatusUptime = ' MySQL   %s.    %s.';
$strServerTabProcesslist = '';
$strServerTabVariables = '';
$strServerTrafficNotes = '<b></b>:        MySQL     .';
$strServerVars = '   ';
$strServerVersion = ' ';
$strSessionValue = ' ';
$strSetEnumVal = '   "enum"  "set",     : \'a\',\'b\',\'c\'...<br />       ("\"")    ("\'")   ,       (, \'\\\\xyz\'  \'a\\\'b\').';
$strShow = '';
$strShowAll = ' ';
$strShowColor = ' ';
$strShowDatadictAs = '  ';
$strShowFullQueries = '  ';
$strShowGrid = ' ';
$strShowPHPInfo = '   PHP';
$strShowTableDimension = '  ';
$strShowTables = ' ';
$strShowThisQuery = '     ';
$strShowingRecords = '  ';
$strSimplifiedChinese = ' ';
$strSingly = '()';
$strSize = '';
$strSlovak = '';
$strSlovenian = '';
$strSort = '';
$strSortByKey = '  ';
$strSpaceUsage = ' ';
$strSpanish = '';
$strSplitWordsWithSpace = ',   (" ").';
$strStatCheckTime = ' ';
$strStatCreateTime = '';
$strStatUpdateTime = ' ';
$strStatement = '';
$strStatus = '';
$strStrucCSV = 'CSV ';
$strStrucData = '  ';
$strStrucDrop = '  ';
$strStrucExcelCSV = 'CSV   MS Excel';
$strStrucNativeExcel = '  MS Excel';
$strStrucOnly = ' ';
$strStructPropose = '  ';
$strStructure = '';
$strSubmit = '';
$strSuccess = ' SQL-   ';
$strSum = '';
$strSwedish = '';
$strSwitchToTable = '   ';

$strTable = ' ';
$strTableComments = '  ';
$strTableEmpty = '  !';
$strTableHasBeenDropped = ' %s  ';
$strTableHasBeenEmptied = ' %s  ';
$strTableHasBeenFlushed = '    %s';
$strTableMaintenance = ' ';
$strTableOfContents = '';
$strTableOptions = ' ';
$strTableStructure = ' ';
$strTableType = ' ';
$strTables = '%s ()';
$strTakeIt = '';
$strTblPrivileges = ' ,   ';
$strTextAreaLength = ' -  ,<br />       ';
$strThai = '';
$strTheContent = '   .';
$strTheContents = '            .';
$strTheTerminator = '  .';
$strTheme = ' / ';
$strThisHost = ' ';
$strThisNotDirectory = '   ';
$strThreadSuccessfullyKilled = 'Thread %s  .';
$strTime = '';
$strToggleScratchboard = 'toggle scratchboard';
$strTotal = '';
$strTotalUC = '';
$strTraditionalChinese = ' ';
$strTraditionalSpanish = ' ';
$strTraffic = '';
$strTransformation_application_octetstream__download = '      .  :    .  :          .     ,   ,          ';
$strTransformation_image_jpeg__inline = ' ,    ; : ,   (  )';
$strTransformation_image_jpeg__link = '    (direct blob download, i.e.).';
$strTransformation_image_png__inline = 'See image/jpeg: inline';
$strTransformation_text_plain__dateformat = '  TIME, TIMESTAMP  DATETIME          .   -   ( ),     timestamp ( : 0).   -        ,    PHP strftime().';
$strTransformation_text_plain__external = ' LINUX:         .    .   Tidy,   HTML .   ,      libraries/transformations/text_plain__external.inc.php   ,    .   -   ,    ,  -   .     1   ,  htmlspecialchars() (  1).     1  NOWRAP,         (  1)';
$strTransformation_text_plain__formatted = '   .   .';
$strTransformation_text_plain__imagelink = '   ,    ;   -    "http://domain.com/",  -   ,  - .';
$strTransformation_text_plain__link = ' ,    ;   -    "http://domain.com/",  -   .';
$strTransformation_text_plain__substr = '   .   -  ,      (  0).   -    .   ,     .    ,     ,   . ( : ...) .';
$strTruncateQueries = '  ';
$strTurkish = '';
$strType = '';

$strUkrainian = '';
$strUncheckAll = '   ';
$strUnicode = '';
$strUnique = '';
$strUnknown = '';
$strUnselectAll = '   ';
$strUpdComTab = ',    Column_comments   ';
$strUpdatePrivMessage = '   ';
$strUpdateProfileMessage = '  .';
$strUpdateQuery = ' ';
$strUpgrade = '   %s   %s  .';
$strUsage = '';
$strUseBackquotes = '      ';
$strUseHostTable = '  ';
$strUseTables = ' ';
$strUseTextField = '  ';
$strUseThisValue = '  ';
$strUser = '';
$strUserAlreadyExists = ' %s  !';
$strUserEmpty = '  !';
$strUserName = ' ';
$strUserNotFound = '       .';
$strUserOverview = 'User overview';
$strUsersDeleted = '    .';
$strUsersHavingAccessToDb = '     &quot;%s&quot;';

$strValidateSQL = ' SQL';
$strValidatorError = ' SQL    . ,       PHP,   %s%s.';
$strValue = '';
$strVar = '';
$strViewDump = '  ';
$strViewDumpDB = '  ';
$strViewDumpDatabases = '  () ';

$strWebServerUploadDirectory = ',      web-';
$strWebServerUploadDirectoryError = ',     "upload"    ';
$strWelcome = '   %s';
$strWestEuropean = '-';
$strWildcard = '';
$strWindowNotFound = '      . ,           -  ';
$strWithChecked = ' :';
$strWritingCommentNotPossible = '  ';
$strWritingRelationNotPossible = '  ';
$strWrongUser = ' /.   .';

$strXML = 'XML';

$strYes = '';

$strZeroRemovesTheLimit = ':      0 ()  .';
$strZip = '  zip';

$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate

$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strRoutines = 'Routines';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
